#![warn(clippy::all, rust_2018_idioms)]
#![cfg_attr(not(debug_assertions), windows_subsystem = "windows")] // hide console window on Windows in release

#[cfg(not(target_arch = "wasm32"))]
fn main() {
    // Log to stdout (if you run with `RUST_LOG=debug`).
    tracing_subscriber::fmt::init();

    let native_options = eframe::NativeOptions::default();
    eframe::run_native(
        "MPC Valet",
        native_options,
        Box::new(|cc| Box::new(mpc_valet::TemplateApp::new(cc))),
    );
}

#[cfg(target_arch = "wasm32")]
fn main() {
    // Unused
}
